@@ -5,6 +5,7 @@ import time
 import logging
 from uuid import uuid4
 import abc
+from collections import defaultdict
 
 from .script import BaseScript
 
@@ -13,6 +14,32 @@ logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
 
+class CachedFinishedJobsMixin:
+    def __init__(self):
+        super().__init__()
+        self.__finished_cache = {}
+        self.__update_finished_cache_called = defaultdict(bool)
+
+    def update_finished_cache(self, project_id):
+        logger.debug("Initiating finished cache update.")
+        if not self.__update_finished_cache_called[project_id]:
+            for job in self.get_owned_jobs(project_id, state=["finished"], meta=["close_reason"]):
+                if job["key"] in self.__finished_cache:
+                    break
+                self.__finished_cache[job["key"]] = job["close_reason"]
+            logger.info(f"Finished jobs cache length: {len(self.__finished_cache)}")
+        self.__update_finished_cache_called[project_id] = True
+
+    def is_finished(self, jobkey):
+        project_id = jobkey.split("/", 1)[0]
+        self.update_finished_cache(project_id)
+        return self.__finished_cache.get(jobkey)
+
+    def _base_loop_tasks(self):
+        for project_id in self.__update_finished_cache_called.keys():
+            self.__update_finished_cache_called[project_id] = False
+
+
 class WorkFlowManager(BaseScript, abc.ABC):
 
     # --max-running-job command line option overrides it
@@ -52,6 +79,10 @@ class WorkFlowManager(BaseScript, abc.ABC):
         assert "state" in kwargs, "'state' parameter must be provided."
         kwargs["has_tag"] = [f"FLOW_ID={self.flow_id}"]
         parent_tag = f"PARENT_NAME={self.name}"
+        meta = kwargs.get("meta") or []
+        if "tags" not in meta:
+            meta.append("tags")
+        kwargs["meta"] = meta
         for job in self.get_jobs(project_id, **kwargs):
             if parent_tag in job["tags"]:
                 yield job
@@ -66,6 +97,8 @@ class WorkFlowManager(BaseScript, abc.ABC):
 
     def add_argparser_options(self):
         super().add_argparser_options()
+        if not self.name:
+            self.argparser.add_argument("name", help="Script name.")
         self.argparser.add_argument(
             "--loop-mode",
             help="If provided, manager will run in loop mode, with a cycle\
@@ -82,6 +115,12 @@ class WorkFlowManager(BaseScript, abc.ABC):
                                     Default: %(default)s",
         )
 
+    def parse_args(self):
+        args = super().parse_args()
+        if not self.name:
+            self.name = args.name
+        return args
+
     def wait_for(self, jobs_keys, interval=60, timeout=float("inf"), heartbeat=None):
         """Waits until all given jobs are not running anymore or until the
         timeout is reached, if a heartbeat is given it'll log an entry every
@@ -101,17 +140,16 @@ class WorkFlowManager(BaseScript, abc.ABC):
                 if self.is_running(key):
                     if time_waited >= next_heartbeat:
                         next_heartbeat += heartbeat
-                        logger.info("{} still running".format(key))
+                        logger.info(f"{key} still running")
                     break
-                else:
-                    still_running[key] = False
+                still_running[key] = False
 
     def on_start(self):
         pass
 
     def __check_resume_workflow(self):
         resumed_job = None
-        for job in self.get_jobs(status=["finished"], meta=["tags"], has_tag=[f"NAME={self.name}"]):
+        for job in self.get_jobs(state=["finished"], meta=["tags"], has_tag=[f"NAME={self.name}"]):
             if self.get_keyvalue_job_tag("FLOW_ID", job["tags"]) == self.flow_id:
                 resumed_job = job
                 break
@@ -154,8 +192,12 @@ class WorkFlowManager(BaseScript, abc.ABC):
         self.__on_start()
         self._run_loops()
 
+    def _base_loop_tasks(self):
+        pass
+
     def _run_loops(self):
         while self.workflow_loop_enabled:
+            self._base_loop_tasks()
             try:
                 if self.workflow_loop() and self.args.loop_mode:
                     time.sleep(self.args.loop_mode)
