@@ -4,7 +4,6 @@ Base script class for spiders crawl managers.
 import abc
 import json
 import logging
-from random import shuffle
 
 from bloom_filter import BloomFilter
 
@@ -42,7 +41,6 @@ class CrawlManager(WorkFlowManager):
     """
 
     spider = None
-    MIN_CHECK_JOBS = 20
 
     def __init__(self):
         super().__init__()
@@ -99,27 +97,17 @@ class CrawlManager(WorkFlowManager):
     def check_running_jobs(self):
         outcomes = {}
         running_job_keys = list(self._running_job_keys)
-        shuffle(running_job_keys)
-        removed = 0
-        for count, jobkey in enumerate(running_job_keys, start=1):
+        while running_job_keys:
+            jobkey = running_job_keys.pop()
             if (outcome := self.is_finished(jobkey)) is not None:
-                _LOG.info(f"Job {jobkey} finished with outcome {outcome}.")
                 spider, spider_args_override = self._running_job_keys.pop(jobkey)
-                removed += 1
                 if outcome in self.failed_outcomes:
+                    _LOG.warning(f"Job {jobkey} finished with outcome {outcome}.")
                     if spider_args_override is not None:
                         spider_args_override = spider_args_override.copy()
                     self.bad_outcome_hook(spider, outcome, spider_args_override, jobkey)
                 outcomes[jobkey] = outcome
-            else:
-                _LOG.info(f"Job {jobkey} still running.")
-                # if some jobs are running don't waste unneeded requests to get status of other jobs.
-                # this is particularly important on crawl managers that handle hundreds of jobs in parallel.
-                # so here we limit number of checked jobs.
-                # However, we also need to ensure that a minimal number of jobs are checked for faster
-                # detection of free slots and scheduling of new jobs.
-                if count - removed > self.MIN_CHECK_JOBS:
-                    break
+        _LOG.info(f"There are {len(self._running_job_keys)} jobs still running.")
 
         return outcomes
 
@@ -131,7 +119,7 @@ class CrawlManager(WorkFlowManager):
         outcomes = self.check_running_jobs()
         if outcomes:
             return False
-        elif not self._running_job_keys:
+        if not self._running_job_keys:
             self.schedule_spider()
         return True
 
@@ -242,8 +230,7 @@ class GeneratorCrawlManager(CrawlManager):
             except StopIteration:
                 if self._running_job_keys:
                     break
-                else:
-                    return False
+                return False
         return True
 
     @staticmethod
