@@ -58,6 +58,7 @@ class BaseScript(ArgumentParserScript):
         self.close_reason = None
         self.__flow_tags = []
         super().__init__()
+        self.set_flow_id_name(self.args)
 
     def append_flow_tag(self, tag):
         """
@@ -78,16 +79,18 @@ class BaseScript(ArgumentParserScript):
             self.flow_id = self.generate_flow_id()
         if self.flow_id:
             tags = [f"FLOW_ID={self.flow_id}"]
-        self.name = name_from_tag or args.name or self.name
+        self.name = name_from_tag or self.name
         if self.name:
             tags.append(f"NAME={self.name}")
         self.add_job_tags(tags=tags)
 
     def add_argparser_options(self):
         self.argparser.add_argument(
-            "--project-id", help="Overrides target project id.", type=int, default=self.default_project_id,
+            "--project-id",
+            help="Overrides target project id.",
+            type=int,
+            default=self.default_project_id,
         )
-        self.argparser.add_argument("--name", help="Script name.")
         self.argparser.add_argument("--flow-id", help="If given, use the given flow id.")
         self.argparser.add_argument(
             "--children-tag",
@@ -106,7 +109,6 @@ class BaseScript(ArgumentParserScript):
         if not self.project_id:
             self.argparser.error("Project id not provided.")
 
-        self.set_flow_id_name(args)
         return args
 
     def get_project(self, project_id=None):
@@ -114,8 +116,7 @@ class BaseScript(ArgumentParserScript):
 
     @dash_retry_decorator
     def get_job_metadata(self, jobkey=None):
-        """If jobkey is None, get own metadata
-        """
+        """If jobkey is None, get own metadata"""
         jobkey = jobkey or os.getenv("SHUB_JOBKEY")
         if jobkey:
             project_id = jobkey.split("/", 1)[0]
@@ -126,8 +127,7 @@ class BaseScript(ArgumentParserScript):
 
     @dash_retry_decorator
     def get_job(self, jobkey=None):
-        """If jobkey is None, get own metadata
-        """
+        """If jobkey is None, get own metadata"""
         jobkey = jobkey or os.getenv("SHUB_JOBKEY")
         if jobkey:
             project_id = jobkey.split("/", 1)[0]
@@ -136,8 +136,7 @@ class BaseScript(ArgumentParserScript):
         logger.warning("SHUB_JOBKEY not set: not running on ScrapyCloud.")
 
     def get_job_tags(self, jobkey=None):
-        """If jobkey is None, get own tags
-        """
+        """If jobkey is None, get own tags"""
         metadata = self.get_job_metadata(jobkey)
         if metadata:
             return dict(self._list_metadata(metadata)).get("tags", [])
@@ -164,8 +163,7 @@ class BaseScript(ArgumentParserScript):
         return metadata.get(key)
 
     def add_job_tags(self, jobkey=None, tags=None):
-        """If jobkey is None, add tags to own list of tags.
-        """
+        """If jobkey is None, add tags to own list of tags."""
         if tags:
             update = False
             job_tags = self.get_job_tags(jobkey)
@@ -182,8 +180,7 @@ class BaseScript(ArgumentParserScript):
                     self._update_metadata(metadata, {"tags": job_tags})
 
     def _get_flowid_name_from_tags(self, jobkey=None):
-        """If jobkey is None, get flowid from own tags
-        """
+        """If jobkey is None, get flowid from own tags"""
         tags = self.get_job_tags(jobkey)
         flow_id = self.get_keyvalue_job_tag("FLOW_ID", tags)
         name = self.get_keyvalue_job_tag("NAME", tags)
@@ -202,7 +199,12 @@ class BaseScript(ArgumentParserScript):
     @dash_retry_decorator
     def _schedule_job(self, spider: str, tags=None, units=None, project_id=None, **kwargs):
         project = self.get_project(project_id)
-        schedule_kwargs = dict(spider=spider, add_tag=self._make_children_tags(tags), units=units, **kwargs,)
+        schedule_kwargs = dict(
+            spider=spider,
+            add_tag=self._make_children_tags(tags),
+            units=units,
+            **kwargs,
+        )
         logger.info("Scheduling a job:\n%s", schedule_kwargs)
         try:
             job = project.jobs.run(**schedule_kwargs)
@@ -234,9 +236,9 @@ class BaseScript(ArgumentParserScript):
     @dash_retry_decorator
     def get_jobs(self, project_id=None, **kwargs):
         kwargs = kwargs.copy()
-        kwargs["start"] = 0
         max_count = kwargs.get("count") or float("inf")
         kwargs["count"] = min(1000, max_count)
+        kwargs["start"] = 0
         seen = set()
         while True:
             count = 0
@@ -248,11 +250,18 @@ class BaseScript(ArgumentParserScript):
                     if len(seen) == max_count:
                         count = 0
                         break
-            if count < kwargs["count"]:
+            if count == 0:
                 break
-            else:
-                shift = len(seen)
-                kwargs["start"] += shift
+            kwargs["start"] += count
+
+    def get_jobs_with_tags(self, spider, tags, project_id=None, **kwargs):
+        """
+        Get jobs with target tags
+        """
+        has_tag, tags = tags[:1], tags[1:]
+        for spider_job in self.get_jobs(project_id, spider=spider, has_tag=has_tag, **kwargs):
+            if not set(tags).difference(spider_job["tags"]):
+                yield self.get_project().jobs.get(spider_job["key"])
 
     @dash_retry_decorator
     def is_running(self, jobkey):
@@ -268,7 +277,7 @@ class BaseScript(ArgumentParserScript):
 
     def is_finished(self, jobkey):
         """
-        Checks whether a job is running. if so, return close_reason. Otherwise return None.
+        Checks whether a job is finished. if so, return close_reason. Otherwise return None.
         """
         metadata = self.get_job_metadata(jobkey)
         if self._get_metadata_key(metadata, "state") == "finished":
